@@ -96,6 +96,9 @@ event_stop_button_pressed (int *i_stop)
 /**
  * @brief  Prepare file name from directory path and Pexels photo url.
  *
+ * Function combines path where file should be saved with its prepared name.
+ * After that it appends extension got from original download url.
+ *
  * @param[in] s_dir   Directory for file write
  * @param[in] si_item SearchItem with url
  * @result    File path
@@ -126,24 +129,26 @@ static GList *
 download_progress_window (GtkWindow *gw_parent,
                           GList     *gl_item_list)
 {
-    GtkWidget  *gw_window;
-    GtkWidget  *gw_label;
-    GtkWidget  *gw_progress;
-    GtkWidget  *gw_box_main;
-    GtkWidget  *gw_stop_button;
-    SearchItem *si_item;
-    GList      *gl_item  = NULL;
-    GList      *gl_res   = NULL;
+    GtkWidget  *gw_window;       /* Progress window widget */
+    GtkWidget  *gw_label;        /* Label for file name */
+    GtkWidget  *gw_progress;     /* Progress bar */
+    GtkWidget  *gw_box_main;     /* Box for window widgets */
+    GtkWidget  *gw_stop_button;  /* Stop downloading button */
+    SearchItem *si_item;         /* For images from list */
+    GList      *gl_item  = NULL; /* Pointer to list */
+    GList      *gl_res   = NULL; /* Result list with downloaded files */
     const char *s_format = "<span style=\"italic\">%s</span>";
-    char       *s_markup = NULL;
-    char       *s_wpdir  = NULL;
-    char       *s_fn     = NULL;
-    char       *s_err    = NULL;
-    float       f_step   = 0;
-    float       f_frac   = 0;
-    int         i_stop   = 0;
-    int         i_perm   = 0;
+    char       *s_markup = NULL; /* For label's markup */
+    char       *s_wpdir  = NULL; /* Path to wallpaper directory */
+    char       *s_fn     = NULL; /* File path for wallpaper save */
+    char       *s_err    = NULL; /* Error output */
+    float       f_step   = 0;    /* Progress bar step */
+    float       f_frac   = 0;    /* Fraction for progress bar to set */
+    int         i_stop   = 0;    /* To set when stop button is pressed */
+    int         i_perm   = 0;    /* For checking save dir permissions */
 
+    /* Getting wallpaper save path and checking it's permissions, creating if
+     * it doesn't exist */
     s_wpdir = cfgfile_get_app_wallpaper_path ();
     i_perm  = dir_check_permissions (s_wpdir);
 
@@ -154,10 +159,11 @@ download_progress_window (GtkWindow *gw_parent,
         return NULL;
     }
 
+    /* Setting progress step and making a pointer to list */
     f_step  = (float) 1.0 / (float) g_list_length (gl_item_list);
-    f_frac  = 0;
     gl_item = gl_item_list;
 
+    /* Creating progress window with widgets */
     gw_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
     gtk_window_set_transient_for (GTK_WINDOW (gw_window), gw_parent);
@@ -194,6 +200,7 @@ download_progress_window (GtkWindow *gw_parent,
     gtk_container_add (GTK_CONTAINER (gw_window), gw_box_main);
     gtk_widget_show_all (gw_window);
 
+    /* Processing list of wallpapers to download */
     while (gl_item != NULL) {
         if (i_stop == 1)
             break;
@@ -352,7 +359,6 @@ combo_set_active_str (GtkWidget  *gw_combo,
         gls_slstore = GTK_LIST_STORE (gtk_combo_box_get_model (
                     GTK_COMBO_BOX (gw_combo)));
 
-        gtk_list_store_append (gls_slstore, &gti_iter);
         gtk_list_store_set (gls_slstore, &gti_iter, i_col, s_val, -1);
     }
 }
@@ -467,7 +473,7 @@ pexels_settings_dialog (const char *s_cfg_file)
 
     if (i_res == GTK_RESPONSE_ACCEPT) {
         const char *s_api = gtk_entry_get_text (GTK_ENTRY (gw_api_entry));
-        
+
         if ((i_err = setts_update_pexels_api (s_cfg_file, s_api)) == ERR_OK) {
             s_result = strdup (s_api);
         }
@@ -717,7 +723,7 @@ sel_combo_check_exist (GtkTreeModel *gtm_model,
     b_res = gtk_tree_model_get_iter_first (gtm_model, &gti_iter);
 
     while (b_res) {
-    
+
         gtk_tree_model_get (gtm_model, &gti_iter,
                             WW_SELCOMBO_ID, &i_read_id,
                             -1);
